ExampleRegistry class

Runtime registry (code generators will call basic type generation)

Constructors

ExampleRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clear all registered generators (mainly for testing)
exampleOf<T>({Seed? seed, Map<String, Object?>? hints}) → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register<T>(TypeExample<T> gen) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ExampleRegistry
final